"use strict";

module.exports = function (action) {
  // namespace variable
  var ns = {};

  if (typeof action !== "string" || !action) {
    return;
  }

  ns.action = action.toUpperCase();
  ns.REQUEST = ns.action + "_REQUEST";
  ns.SUCCESS = ns.action + "_SUCCESS";
  ns.FAILURE = ns.action + "_FAILURE";

  ns.request = function () {
    return {
      type: ns.REQUEST
    };
  };

  ns.success = function (response) {
    return {
      type: ns.SUCCESS,
      response: response
    };
  };

  ns.failure = function (error) {
    return {
      type: ns.FAILURE,
      error: error
    };
  };

  ns.defaultState = {
    isLoading: false,
    isDone: false,
    error: null,
    response: {}
  };

  ns.reducer = function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : ns.defaultState;
    var action = arguments.length > 1 ? arguments[1] : undefined;

    switch (action.type) {
      case ns.REQUEST:
        return Object.assign({}, state, {
          isLoading: true
        });

      case ns.SUCCESS:
        return Object.assign({}, state, {
          isLoading: false,
          done: true,
          response: action.response
        });

      case ns.FAILURE:
        return Object.assign({}, state, {
          isLoading: false,
          done: false,
          error: action.error
        });

      default:
        return state;
    }
  };

  return ns;
};